#[repr(C)]pub struct DeviceGetSampleResponse {
pub value: u32,
}Fields
value: u32Trait Implementations
Sourceimpl Clone for DeviceGetSampleResponse
impl Clone for DeviceGetSampleResponse
Sourcefn clone(&self) -> DeviceGetSampleResponse
fn clone(&self) -> DeviceGetSampleResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetSampleResponse
impl Debug for DeviceGetSampleResponse
Sourceimpl<D: ResourceDialect> Decode<DeviceGetSampleResponse, D> for DeviceGetSampleResponse
impl<D: ResourceDialect> Decode<DeviceGetSampleResponse, D> for DeviceGetSampleResponse
Sourceimpl<D: ResourceDialect> Encode<DeviceGetSampleResponse, D> for &DeviceGetSampleResponse
impl<D: ResourceDialect> Encode<DeviceGetSampleResponse, D> for &DeviceGetSampleResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<DeviceGetSampleResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<DeviceGetSampleResponse, D> for (T0,)
Sourceimpl Hash for DeviceGetSampleResponse
impl Hash for DeviceGetSampleResponse
Sourceimpl Ord for DeviceGetSampleResponse
impl Ord for DeviceGetSampleResponse
Sourcefn cmp(&self, other: &DeviceGetSampleResponse) -> Ordering
fn cmp(&self, other: &DeviceGetSampleResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetSampleResponse
impl PartialEq for DeviceGetSampleResponse
Sourceimpl PartialOrd for DeviceGetSampleResponse
impl PartialOrd for DeviceGetSampleResponse
Sourceimpl TypeMarker for DeviceGetSampleResponse
impl TypeMarker for DeviceGetSampleResponse
Sourcetype Owned = DeviceGetSampleResponse
type Owned = DeviceGetSampleResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceGetSampleResponse
impl ValueTypeMarker for DeviceGetSampleResponse
Sourcetype Borrowed<'a> = &'a DeviceGetSampleResponse
type Borrowed<'a> = &'a DeviceGetSampleResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for DeviceGetSampleResponse
impl Eq for DeviceGetSampleResponse
impl Persistable for DeviceGetSampleResponse
impl StructuralPartialEq for DeviceGetSampleResponse